<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "Modifica o esborra la reserva"; break;
case "Prenotazione a nome di":  		$messaggio = "Reserva a nom de"; break;
case "nato il":  				$messaggio = "nascut el"; break;
case "nata il":  				$messaggio = "nascuda el"; break;
case "e":  					$messaggio = "i"; break;
case "CAP":  					$messaggio = "codi postal"; break;
case "Telefono":  				$messaggio = "Telèfon"; break;
case "2º telefono":  				$messaggio = "2on telèfon"; break;
case "3º telefono":  				$messaggio = "3er telèfon"; break;
case "Modifica i dati del cliente":  		$messaggio = "Modifica les dades del client"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "La reserva és de l'any anterior, només pordà modificar-se la data de sortida"; break;
case "settimane":  				$messaggio = "setmanes"; break;
case "giorni":  				$messaggio = "dies"; break;
case "giorno":  				$messaggio = "day"; break;
case "dal":  					$messaggio = "des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "cambia in":  				$messaggio = "canvia a"; break;
case "in":  					$messaggio = "a"; break;
case "Nº di piano":  				$messaggio = "N° de pis"; break;
case "e/o di casa":  				$messaggio = "i/o de casa"; break;
case "e/o di persone":  			$messaggio = "i/o de persones"; break;
case "Nº di persone":  				$messaggio = "N° de persones"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Cancella il commento":  			$messaggio = "Esborra el comentari"; break;
case "Tipo di tariffa":  			$messaggio = "Tipus de tarifa"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "Sconto":  				$messaggio = "Descompte"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "resto":  					$messaggio = "resta"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Torna a calcular les arres en base a la nova tarifa"; break;
case "Costo aggiuntivo unico":  		$messaggio = "Cost extra puntual"; break;
case "moltiplicato per":  			$messaggio = "multiplicat per"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Cost extra setmanal"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Cost extra diari"; break;
case "per":  					$messaggio = "per"; break;
case "settimane moltiplicato per":  		$messaggio = "setmanes multiplicat per"; break;
case "giorni moltiplicato per":  		$messaggio = "dies multiplicat per"; break;
case "della tariffa moltiplicato per":  	$messaggio = "de la tarifa multiplicat per"; break;
case "Prenotazione confermata":  		$messaggio = "Reserva confirmada"; break;
case "Totale da pagare":  			$messaggio = "Total a pagar"; break;
case "Pagato":  				$messaggio = "Pagat"; break;
case "aggiungi":  				$messaggio = "afegeix-hi"; break;
case "pagato tutto":  				$messaggio = "tod pagat"; break;
case "caparra ":  				$messaggio = "arres pagades"; break;
case "Ancora da pagare":  			$messaggio = "Manca per pagar"; break;
case "Nuovo costo aggiuntivo unico":  		$messaggio = "Nou suplement puntual"; break;
case "di":  					$messaggio = "de"; break;
case "da moltiplicare per":  			$messaggio = "a multiplicar per"; break;
case "letto":  					$messaggio = "llit"; break;
case "straordinario":  				$messaggio = "suplement"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "Nou suplement setmanal"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "Nou suplement diari"; break;
case "nº di settimane da applicare":  		$messaggio = "n° de setmanes a aplicar"; break;
case "nº di giorni da applicare":  		$messaggio = "n° de dies a aplicar"; break;
case "non specificato":  			$messaggio = "no especificat"; break;
case "Modifica la prenotazione":  		$messaggio = "Modifica la reserva"; break;
case "Cancella la prenotazione":  		$messaggio = "Esborra la reserva"; break;
case "documento di tipo":  			$messaggio = "document tipus"; break;
case "visualizza":  				$messaggio = "veure"; break;
case "visualizza il documento":  		$messaggio = "veure el document"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "SI":  					$messaggio = "SÍ"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "esborra també els imports ja cobrats"; break;
case "NO":  					$messaggio = "NO"; break;
case "La prenotazione":  			$messaggio = "La reserva"; break;
case "era già stata cancellata":  		$messaggio = "ja era esborrada"; break;
case "Prenotazione":  				$messaggio = "Reserva"; break;
case "cancellata":  				$messaggio = "esborrada"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>no ha estat esborrada</b> perquè ha estat modificada per un altre usuari mentre s'omplia el formulari"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "Segur que cal <b>esborrar</b> la reserva"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "Segur que cal <b>esborrar</b> les reserves"; break;
case "La data iniziale verrà cambiata dal":  	$messaggio = "La data d'arribada canviarà de"; break;
case "al":  					$messaggio = "a"; break;
case "La data finale verrà cambiata dal":  	$messaggio = "La data de sortida canviarà de"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "Les <div style=\"display: inline; color: red;\">dates</div> són <b>errònies</b>"; break;
case "°</b> piano":  				$messaggio = "º </b> pis"; break;
case "della casa":  				$messaggio = "de la casa"; break;
case "con massimo numero di occupanti":  	$messaggio = "amb màxim número d'ocupants"; break;
case "a":  					$messaggio = "a"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "El número de persones canviarà de"; break;
case "persone":  				$messaggio = "persones"; break;
case "è stata <b>cancellata</b>":  		$messaggio = "ha estat <b>esborrada</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Cal fer els moviments següents als períodes de la  <div style=\"display: inline; color: blue;\">regla d'assignació 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "La reserva des del"; break;
case "a nome di":  				$messaggio = "a nom de"; break;
case "La prenotazione verrà":  			$messaggio = "La reserva serà"; break;
case "mantenuta":  				$messaggio = "mantinguda"; break;
case "spostata":  				$messaggio = "moguda"; break;
case "La tariffa":  				$messaggio = "La tarifa"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "ja no existeix, cal canviar-la abans d'actualitzar"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "Encara <b>no</b> s'ha inserit el preu de la"; break;
case "per la settimana dal":  			$messaggio = "per la setmana des del"; break;
case "per il giorno dal":  			$messaggio = "pel dia des del"; break;
case "La tariffa verrà cambiata da":  		$messaggio = "La tarifa canviarà de"; break;
case "Il costo aggiuntivo":  			$messaggio = "El suplement"; break;
case "Il costo aggiuntivo unico":  		$messaggio = "El suplement puntual"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "El suplement setmanal"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "El suplement diari"; break;
case "non può essere moltiplicato per":  	$messaggio = "no pot multiplicar-se per"; break;
case "verrà moltiplicato per":  		$messaggio = "serà multiplicat por"; break;
case "prima era":  				$messaggio = "abans era"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "Les setmanes del suplement"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "Els dies del suplement"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>superen</b> la durada de la reserva"; break;
case "verranno cabiate da":  			$messaggio = "canviaran de"; break;
case "verranno cabiati da":  			$messaggio = "canviaran de"; break;
case "verranno cabiate":  			$messaggio = "canviaran"; break;
case "verranno cabiati":  			$messaggio = "canviaran"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "<b>no</b> seran canviades"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "<b>no</b> seran canviats"; break;
case "su":  					$messaggio = "sobre"; break;
case "Il prezzo del costo aggiuntivo":  	$messaggio = "El preu del suplement"; break;
case "verrà tolto":  				$messaggio = "será substret"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Les dades del suplement <b>suplement</b> són <div style=\"display: inline; color: red;\">errònies o mancants</div>"; break;
case "verrà aggiunto":  			$messaggio = "serà afegit"; break;
case "come letto aggiuntivo":  			$messaggio = "com a llit addicional"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "Les setmanes del nou suplement"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "Els dies del nou suplement"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "El <div style=\"display: inline; color: red;\">descompte</div> inserit"; break;
case "supera il costo totale senza sconto":  	$messaggio = "supera el cost total sense descompte"; break;
case "Lo sconto verrà cambiato da":  		$messaggio = "El descompte canviarà de"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "La <div style=\"display: inline; color: red;\">arres</div> inserida"; break;
case "supera il costo totale":  		$messaggio = "supera el cost total"; break;
case "La caparra verrà cambiata da":  		$messaggio = "Les arres canviaran de"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "La <div style=\"display: inline; color: red;\">arres</div>"; break;
case "supera il nuovo costo totale":  		$messaggio = "supera el nou cost total"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio = "L'import <div style=\"display: inline; color: red;\">pagat</div> inserit"; break;
case "I soldi pagati verranno cambiati da":  		$messaggio = "L'import pagat canviarà de"; break;
case "verrà <b>confermata</b>":  			$messaggio = "serà <b>confirmada</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "Es suprimirà la <b>confirmació</b> de la reserva"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "El <b>comentari</b> canviarà"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "El <b>comentari</b> serà esborrat"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "modificata":  				$messaggio = "modificada"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>no ha estat modificada</b> perquè la taula de reserves ha estat modificada per un altre usuari mentre s'omplia el formulari"; break;
case "verrà cambiato da":  			$messaggio = "canviarà de"; break;
case "con costo agg.":  			$messaggio = "amb suplement"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "No hi ha cap període de les regles 1 al qual s'hi permeti inserir reserves a l'usuari"; break;
case "Prenotazione non confermata":  		$messaggio = "Reserva no confirmada"; break;
case "Inserita dall'utente":  			$messaggio = "Inserida per l'usuari"; break;
case "Si considererà l'utente":  		$messaggio = "L'usuari"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "serà considerat com a l'inseridor de la reserva"; break;
case "Non si possono inserire altri costi":  	$messaggio = "No es poden inserir més costos"; break;
case "in questo periodo, già":  		$messaggio = "a aquest període, ja"; break;
case "presenti":  				$messaggio = "presents"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "No es pot inerir el suplement"; break;
case "in questo periodo":  			$messaggio = "a aquest període"; break;
case "Settimane":  				$messaggio = "Setmanes"; break;
case "Giorni":  				$messaggio = "Dies"; break;
case "mostra":  				$messaggio = "mostra"; break;
case "nascondi":  				$messaggio = "oculta"; break;
case "numeri diversi":  			$messaggio = "números diferents"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "No es pot inserir més d'un suplement amb import percentual sobre el preu total per cada reserva"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "Escollir les setmanes a les quals d'aplicarà el suplement"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "Escollir els dies als quals s'aplicarà el suplement"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Cal inserir el número de persones pel suplement"; break;
case "Non si possono inserire altri costi":  	$messaggio = "No es pot inserir més costos"; break;
case "in questo periodo, già":  		$messaggio = "a aquest període, ja"; break;
case "presenti":  				$messaggio = "presents"; break;
case "della tariffa":  				$messaggio = "de la tarifa"; break;
case "del totale":  				$messaggio = "del total"; break;
case "della caparra":  				$messaggio = "de les arres"; break;
case "del resto caparra":  			$messaggio = "de la resta de les arres"; break;
case "di base":  				$messaggio = "de base"; break;
case "registra entrata":  			$messaggio = "enregistrar entrada"; break;
case "cancella entrata":  			$messaggio = "esborrar entrada"; break;
case "registra uscita":  			$messaggio = "enregistrar sortida"; break;
case "cancella uscita":  			$messaggio = "esborrar sortida"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atenció</div>: horari d'entrada ja enregistrar"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atenció</div>: horari d'entrada no enregistrat"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Atencin</div>: horari de sortida ja enregistrat"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Atenció</div>: horari de sortida no enregistrat, primer cal enregistrar l'entrada"; break;
case "Metodo pagamento caparra":  		$messaggio = "Mitjà de pagament de les arres"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "El mitjà de pagament de les arres canviarà a"; break;
case "Metodo di pagamento":  			$messaggio = "Mitjà de pagament"; break;
case "metodo di pagamento":  			$messaggio = "mitjà de pagament"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normalment les reserves ja iniciades i les que han enregistrat l'horari d'entrada no es mouen"; break;
case "Prova di nuovo":  			$messaggio = "Intenta de nou"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "movent també les reserves començades després del"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "considerades fixes porquè <div style=\"display: inline; color: red;\">a dia d'avui ja són iniciades</div>"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "és incompatible amb la tarifa seleccionada"; break;
case "non può essere applicato":  		$messaggio = "no pot aplicar-se"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "No es pot canviar l'assignació d'una reserva que es trobi <div style=\"display: inline; color: red;\">entre dos anys</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "Modifica a l'any anterior"; break;
case "Orario entrata stimato":  		$messaggio = "Horari orientatiu d'arribada"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "L'horari orientatiu d'arribada canviarà a"; break;
case "Codice prenotazione":  			$messaggio = "Codi reserva"; break;
case "rigenera":  				$messaggio = "regenerar"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "No s'ha pogut moure la reserva perquè l'arribada ja és enregistrada"; break;
case "Cambia cliente":  			$messaggio = "Canviar client"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "Nou titular de la reserva"; break;
case "cliente numero":  			$messaggio = "client número"; break;
case "Il titolare della prenotazione":  	$messaggio = "El titular de la reserva"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "El titular de les reserves"; break;
case "Cliente non trovato":  			$messaggio = "No s'ha trobat el client"; break;
case "Annulla":  				$messaggio = "Anul·lar"; break;
case "Prenotazioni vicine":  			$messaggio = "Reserves properes"; break;
case "numero":  				$messaggio = "número"; break;
case "La prenotazione numero":  		$messaggio = "La reserva número"; break;
case "non esiste":  				$messaggio = "no existeix"; break;
case "Ospiti della prenotazione":  		$messaggio = "Hostes de la reserva"; break;
case "Modifica gli ospiti":  			$messaggio = "Modifica els hostes"; break;
case "nato":  					$messaggio = "nascut"; break;
case "nata":  					$messaggio = "nascuda"; break;
case "il":  					$messaggio = "el"; break;
case " a":  					$messaggio = " a"; break;
case "scade":  					$messaggio = "caduca"; break;
case "Codice fiscale":  			$messaggio = "Codi fiscal"; break;
case "Origine":  				$messaggio = "Origen"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "L'origen de la reserva canviarà a"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "Modifica o esborra les reserves"; break;
case "Modifica le prenotazioni":  		$messaggio = "Modifica les reserves"; break;
case "Cancella le prenotazioni":  		$messaggio = "Esborra les reserves"; break;
case "della prenotazione":  			$messaggio = "de la reserva"; break;
case "per la prenotazione":  			$messaggio = "per la reserva"; break;
case "Data inserimento":  			$messaggio = "Data d'inserció"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "amb els suplements seleccionats"; break;
case "I beni richiesti dal costo":  		$messaggio = "Els béns necessaris pel cost"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "no són disponibles a l'inventari"; break;
case "pren.":  					$messaggio = "rva."; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "Cal inserir el <span class=\"colred\">número de persones</span> per la tarifa seleccionada"; break;
case "Partita iva":  				$messaggio = "NIF/CIF"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "els béns necessaris per enregistrar l'entrada"; break;
case "Commissioni":  				$messaggio = "Comissions"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Torna a calcular les comissions en base a la nova tarifa"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Les comissions canviaran des de"; break;
case "tasse":  					$messaggio = "impostos"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "El preu total canviarà de"; break;
case "saldo di":  				$messaggio = "saldo de"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Altres reserves del mateix client al mateix període"; break;
case "tutte":  					$messaggio = "totes"; break;
case "Attenzione":  				$messaggio = "Atenció"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "hi ha d'altres reserves del mateix client al mateix període que encara no han estat pagades"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "El saldo total pagat será de"; break;
case "ln.":  					$messaggio = "idioma"; break;
case "della tariffa fissa":  			$messaggio = "de la tarifa fixa"; break;
case "di una persona":  			$messaggio = "d'una persona"; break;
case "non può essere moltiplicato per più di":	$messaggio = "no pot multiplicar-se per més de"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "Nou suplement"; break;
case "id op.":  				$messaggio = "id"; break;
case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
case "Cliente":  				$messaggio = "Client"; break;
case "totale":  				$messaggio = "total"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "cambia il commento":  			$messaggio = "change comment"; break;
case "Il commento":  				$messaggio = "Comment"; break;
case "verrà cambiato":  			$messaggio = "will be changed"; break;
case "per ":  					$messaggio = "for "; break;
case "Il numero di":  				$messaggio = "The number of"; break;
case "Valuta":  				$messaggio = "Currency"; break;
case "Valuta caparra":  			$messaggio = "Deposit currency"; break;
case "Al cambio attuale":  			$messaggio = "At current exchange rate"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
case "in modo permanente":  			$messaggio = "permanently"; break;
case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
case "Data cancellazione":  			$messaggio = "Deletion date"; break;
case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
case "Per la tariffa selezionata si deve inserire un <span class=\"colred\">numero minimo</span> di":	$messaggio = "For selected rate you have to insert a <span class=\"colred\">minimum number</span> of"; break;
case "persona":  				$messaggio = "person"; break;
case "id operazione":  				$messaggio = "transaction id"; break;
case "Data operazione":  			$messaggio = "Transaction date"; break;
case "Data":  					$messaggio = "Date"; break;
case "Note":  					$messaggio = "Notes"; break;
case "Informazioni extra":  			$messaggio = "Extra info"; break;
case "Inserisci una prenotazione uguale":  	$messaggio = "Insert a reservation like this"; break;
case "Inserisci prenotazioni uguali":  		$messaggio = "Insert reservations like these"; break;
case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Change client also in payments already made"; break;
case "Ripristina la prenotazione":  		$messaggio = "Restore reservation"; break;
case "Ripristina le prenotazioni":  		$messaggio = "Restore reservations"; break;
case "Non si possono inserire prenotazioni nel passato":	$messaggio = "You can't insert reservations in the past"; break;
case "Si è sicuri di voler provare a <b>ripristinare</b> la prenotazione":	$messaggio = "Are you sure you want to try <b>restoring</b> the reservation"; break;
case "Si è sicuri di voler provare a <b>ripristinare</b> le prenotazioni":	$messaggio = "Are you sure you want to try <b>restoring</b> reservations"; break;
case "ripristinata":  				$messaggio = "restored"; break;
case "Le date della prenotazione":  		$messaggio = "The reservation dates"; break;
case "non sono attualmente disponibili":  	$messaggio = "are not currently available"; break;
case "sono attualmente chiuse":  		$messaggio = "are currently closed"; break;
case "Le date vanno liberate manualmente prima di poter ripristinare la prenotazione":	$messaggio = "Dates must be manually freed before the reservation can be restored"; break;
case "Le prenotazioni vicine alla prenotazione":	$messaggio = "Reservations nearby reservation"; break;
case "vanno ripristinate manualemnte":  	$messaggio = "must be restored manually"; break;
case "cancellare manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually deleting a reservation coming from interconnections"; break;
case "senza aspettare che venga cancellata dall'interconnessione":	$messaggio = "without waiting for it to be deleted by the interconnection"; break;
case "può creare overbooking":  		$messaggio = "may cause overbooking"; break;
case "rimpicciolire manualmente una prenotazione proveniente dalle interconnessioni":	$messaggio = "manually shrinking a reservation coming from interconnections"; break;
case "senza aspettare che venga modificata dall'interconnessione":	$messaggio = "without waiting for it to be modified by the interconnection"; break;
case "gli altri campi":  			$messaggio = "the other fields"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>